@@ -85,7 +85,7 @@ def protobuf_to_dict(pb, type_callable_map=TYPE_CALLABLE_MAP,
             continue
 
         if field.full_name in ['google.protobuf.Timestamp.seconds'] and human_readable_timestamps:
-            result_dict[field.name] = datetime.fromtimestamp(type_callable(value) / 1e3).strftime('%Y-%m-%d %H:%M:%S.%f')
+            result_dict[field.name] = datetime.fromtimestamp(type_callable(value)).strftime('%Y-%m-%d %H:%M:%S.%f')
         else:
             result_dict[field.name] = type_callable(value)
 
@@ -117,7 +117,7 @@ def protobuf_to_dict(pb, type_callable_map=TYPE_CALLABLE_MAP,
 def _get_field_value_adaptor(pb, field, type_callable_map=TYPE_CALLABLE_MAP,
                              use_enum_labels=False,
                              including_default_value_fields=False,
-                             human_readable_timestamps=True):
+                             human_readable_timestamps=False):
     if field.type == FieldDescriptor.TYPE_MESSAGE:
         # recursively encode protobuf sub-message
         return lambda pb: protobuf_to_dict(
